@@ -443,6 +443,7 @@ request_clos_destroy (gpointer data)
   struct request_clos *c = (struct request_clos *) data;
 
   g_free (c->url);
+  g_clear_object (&c->cancellable);
   g_clear_pointer (&c->headers, g_hash_table_unref);
   g_free (c);
 }
@@ -772,7 +773,7 @@ get_url (GrlNetWc *self,
   c->url = g_strdup (url);
   c->headers = headers? g_hash_table_ref (headers): NULL;
   c->result = result;
-  c->cancellable = cancellable;
+  c->cancellable = cancellable ? g_object_ref (cancellable) : NULL;
 
   g_get_current_time (&now);
 
@@ -961,8 +962,8 @@ grl_net_wc_request_with_headers_hash_async (GrlNetWc *self,
  * grl_net_wc_request_finish:
  * @self: a #GrlNetWc instance
  * @result: The result of the request
- * @content: The contents of the resource
- * @length: (allow-none): The length of the contents or %NULL if it is not
+ * @content: (out) (allow-none) (transfer none): The contents of the resource
+ * @length: (out) (allow-none): The length of the contents or %NULL if it is not
  * needed
  * @error: return location for a #GError, or %NULL
  *
