@@ -515,6 +515,7 @@ grl_media_new_from_pls_entry (const gchar *uri,
   const gchar *title, *thumbnail;
   const gchar *description, *mimetype;
   const gchar *duration_ms;
+  const gchar *audio_track;
 
   GRL_DEBUG ("%s (\"%s\")", __FUNCTION__, uri);
 
@@ -522,7 +523,7 @@ grl_media_new_from_pls_entry (const gchar *uri,
 
   file = g_file_new_for_uri (uri);
   options = grl_operation_options_new (NULL);
-  grl_operation_options_set_flags (options, GRL_RESOLVE_FAST_ONLY);
+  grl_operation_options_set_resolution_flags (options, GRL_RESOLVE_FAST_ONLY);
   media = grl_pls_file_to_media (NULL, file, NULL, FALSE, options);
   g_object_unref (options);
   g_object_unref (file);
@@ -550,6 +551,14 @@ grl_media_new_from_pls_entry (const gchar *uri,
   if (mimetype)
     grl_media_set_mime (media, mimetype);
 
+/* For older totem-pl-parser versions */
+#ifndef TOTEM_PL_PARSER_FIELD_AUDIO_TRACK
+#define TOTEM_PL_PARSER_FIELD_AUDIO_TRACK "audio-track"
+#endif
+  audio_track = g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_AUDIO_TRACK);
+  if (audio_track)
+    grl_data_set_int (GRL_DATA (media), GRL_METADATA_KEY_AUDIO_TRACK, atoi (audio_track));
+
   if (GRL_IS_MEDIA_AUDIO(media)) {
     GrlMediaAudio *audio = GRL_MEDIA_AUDIO(media);
     grl_media_audio_set_album (audio, g_hash_table_lookup (metadata, TOTEM_PL_PARSER_FIELD_ALBUM));
@@ -1133,7 +1142,7 @@ set_container_childcount (GFile               *file,
      so we can only check if the directory is totally empty (no subdirs,
      and no files), otherwise we just say we do not know the actual
      childcount */
-  if (grl_operation_options_get_flags (options) & GRL_RESOLVE_FAST_ONLY) {
+  if (grl_operation_options_get_resolution_flags (options) & GRL_RESOLVE_FAST_ONLY) {
     grl_media_box_set_childcount (GRL_MEDIA_BOX (media),
                                   GRL_METADATA_KEY_CHILDCOUNT_UNKNOWN);
     return;
