@@ -159,6 +159,58 @@ grl_media_audio_set_mb_album_id (GrlMediaAudio *audio, const gchar *mb_album_id)
                        mb_album_id);
 }
 
+/**
+ * grl_media_audio_set_mb_artist_id:
+ * @audio: the media instance
+ * @mb_artist_id: the MusicBrainz artist identifier
+ *
+ * Set the MusicBrainz artist identifier of the audio
+ *
+ * Since: 0.2.12
+ */
+void
+grl_media_audio_set_mb_artist_id (GrlMediaAudio *audio, const gchar *mb_artist_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA_AUDIO (audio));
+  grl_data_set_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_ARTIST_ID,
+                       mb_artist_id);
+}
+
+/**
+ * grl_media_audio_set_mb_recording_id:
+ * @audio: the media instance
+ * @mb_recording_id: the MusicBrainz recording identifier
+ *
+ * Set the MusicBrainz recording identifier of the audio
+ *
+ * Since: 0.2.12
+ */
+void
+grl_media_audio_set_mb_recording_id (GrlMediaAudio *audio,
+                                     const gchar *mb_recording_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA_AUDIO (audio));
+  grl_data_set_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_RECORDING_ID,
+                       mb_recording_id);
+}
+
+/**
+ * grl_media_audio_set_mb_track_id:
+ * @audio: the media instance
+ * @mb_track_id: the MusicBrainz track identifier
+ *
+ * Set the MusicBrainz track identifier of the audio
+ *
+ * Since: 0.2.12
+ */
+void
+grl_media_audio_set_mb_track_id (GrlMediaAudio *audio, const gchar *mb_track_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA_AUDIO (audio));
+  grl_data_set_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_TRACK_ID,
+                       mb_track_id);
+}
+
 /**
  * grl_media_audio_set_bitrate:
  * @audio: the media instance
@@ -269,6 +321,24 @@ grl_media_audio_add_lyrics (GrlMediaAudio *audio, const gchar *lyrics)
   grl_data_add_string (GRL_DATA (audio), GRL_METADATA_KEY_LYRICS, lyrics);
 }
 
+/**
+ * grl_media_audio_add_mb_artist_id:
+ * @audio: the media instance
+ * @mb_artist_id: a MusicBrainz artist identifier
+ *
+ * Adds a new MusicBrainz artist id to @audio.
+ *
+ * Since: 0.2.12
+ **/
+void
+grl_media_audio_add_mb_artist_id (GrlMediaAudio *audio,
+                                  const gchar *mb_artist_id)
+{
+  g_return_if_fail (GRL_IS_MEDIA_AUDIO (audio));
+  grl_data_add_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_ARTIST_ID,
+                       mb_artist_id);
+}
+
 /**
  * grl_media_audio_add_url_data:
  * @audio: the media instance
@@ -452,6 +522,78 @@ grl_media_audio_get_mb_album_id (GrlMediaAudio *audio)
   return grl_data_get_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_ALBUM_ID);
 }
 
+/**
+ * grl_media_audio_get_mb_artist_id:
+ * @audio: the media instance
+ *
+ * Returns: the MusicBrainz artist identifier
+ *
+ * Since: 0.2.12
+ */
+const gchar *
+grl_media_audio_get_mb_artist_id (GrlMediaAudio *audio)
+{
+  g_return_val_if_fail (GRL_IS_MEDIA_AUDIO (audio), NULL);
+  return grl_data_get_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_ARTIST_ID);
+}
+
+/**
+ * grl_media_audio_get_mb_artist_id_nth:
+ * @audio: the media instance
+ * @index: element to retrieve, starting at 0
+ *
+ * Returns: the n-th MusicBrainz artist identifier of the audio
+ *
+ * Since: 0.2.12
+ */
+const gchar *
+grl_media_audio_get_mb_artist_id_nth (GrlMediaAudio *audio, guint index)
+{
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA_AUDIO (audio), NULL);
+
+  relkeys =
+    grl_data_get_related_keys (GRL_DATA (audio),
+                               GRL_METADATA_KEY_MB_ARTIST_ID,
+                               index);
+
+  if (!relkeys) {
+    return NULL;
+  } else {
+    return grl_related_keys_get_string (relkeys, GRL_METADATA_KEY_MB_ARTIST_ID);
+  }
+}
+
+/**
+ * grl_media_audio_get_mb_recording_id:
+ * @audio: the media instance
+ *
+ * Returns: the MusicBrainz recording identifier
+ *
+ * Since: 0.2.12
+ */
+const gchar *
+grl_media_audio_get_mb_recording_id (GrlMediaAudio *audio)
+{
+  g_return_val_if_fail (GRL_IS_MEDIA_AUDIO (audio), NULL);
+  return grl_data_get_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_RECORDING_ID);
+}
+
+/**
+ * grl_media_audio_get_mb_track_id:
+ * @audio: the media instance
+ *
+ * Returns: the MusicBrainz track identifier
+ * Since: 0.2.12
+ */
+const gchar *
+grl_media_audio_get_mb_track_id (GrlMediaAudio *audio)
+{
+  g_return_val_if_fail (GRL_IS_MEDIA_AUDIO (audio), NULL);
+  return grl_data_get_string (GRL_DATA (audio), GRL_METADATA_KEY_MB_TRACK_ID);
+}
+
 /**
  * grl_media_audio_get_bitrate:
  * @audio: the media instance
