@@ -95,6 +95,8 @@ void grl_media_video_set_season (GrlMediaVideo *video, gint season);
 
 void grl_media_video_set_episode (GrlMediaVideo *video, gint episode);
 
+void grl_media_video_set_episode_title (GrlMediaVideo *video, const gchar *episode_title);
+
 void grl_media_video_set_show (GrlMediaVideo *video, const gchar *show);
 
 gint grl_media_video_get_width (GrlMediaVideo *video);
@@ -107,6 +109,8 @@ gint grl_media_video_get_season (GrlMediaVideo *video);
 
 gint grl_media_video_get_episode (GrlMediaVideo *video);
 
+const gchar *grl_media_video_get_episode_title (GrlMediaVideo *video);
+
 const gchar *grl_media_video_get_show (GrlMediaVideo *video);
 
 GType grl_media_video_get_type (void) G_GNUC_CONST;
