@@ -42,7 +42,6 @@ GRL_LOG_DOMAIN(media_log_domain);
 #define RATING_MAX  5.00
 #define SERIAL_STRING_ALLOC 100
 
-static void grl_media_dispose (GObject *object);
 static void grl_media_finalize (GObject *object);
 
 G_DEFINE_TYPE (GrlMedia, grl_media, GRL_TYPE_DATA);
@@ -52,7 +51,6 @@ grl_media_class_init (GrlMediaClass *klass)
 {
   GObjectClass *gobject_class = (GObjectClass *)klass;
 
-  gobject_class->dispose = grl_media_dispose;
   gobject_class->finalize = grl_media_finalize;
 }
 
@@ -61,12 +59,6 @@ grl_media_init (GrlMedia *self)
 {
 }
 
-static void
-grl_media_dispose (GObject *object)
-{
-  G_OBJECT_CLASS (grl_media_parent_class)->dispose (object);
-}
-
 static void
 grl_media_finalize (GObject *object)
 {
@@ -107,7 +99,11 @@ grl_media_new (void)
 void
 grl_media_set_rating (GrlMedia *media, gfloat rating, gfloat max)
 {
-  gfloat normalized_value = (rating * RATING_MAX) / max;
+  gfloat normalized_value;
+
+  g_return_if_fail (GRL_IS_MEDIA (media));
+
+  normalized_value = (rating * RATING_MAX) / max;
   grl_data_set_float (GRL_DATA (media),
 		      GRL_METADATA_KEY_RATING,
 		      normalized_value);
@@ -126,7 +122,11 @@ grl_media_set_rating (GrlMedia *media, gfloat rating, gfloat max)
 void
 grl_media_set_url_data (GrlMedia *media, const gchar *url, const gchar *mime)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA (media));
+
+  relkeys = grl_related_keys_new ();
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_URL, url);
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_MIME, mime);
   grl_data_set_related_keys (GRL_DATA (media), relkeys, 0);
@@ -145,7 +145,11 @@ grl_media_set_url_data (GrlMedia *media, const gchar *url, const gchar *mime)
 void
 grl_media_add_url_data (GrlMedia *media, const gchar *url, const gchar *mime)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA (media));
+
+  relkeys = grl_related_keys_new ();
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_URL, url);
   grl_related_keys_set_string (relkeys, GRL_METADATA_KEY_MIME, mime);
   grl_data_add_related_keys (GRL_DATA (media), relkeys);
@@ -544,7 +548,7 @@ grl_media_unserialize (const gchar *serial)
   if (query) {
     registry = grl_registry_get_default ();
     keys = grl_registry_get_metadata_keys (registry);
-    /* This is a hack: we do it because we know GrlKeyId are actually integers,
+    /* This is a hack: we do it because we know GrlKeyID are actually integers,
        and assigned sequentially (0 is for invalid key). This saves us to use a
        hashtable to store the counter per key */
     grlkey_count = g_new0 (guint, g_list_length(keys) + 1);
@@ -848,7 +852,12 @@ grl_media_set_region_data (GrlMedia *media,
                            const GDateTime *publication_date,
                            const gchar *certificate)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA (media));
+
+  relkeys = grl_related_keys_new ();
+
   grl_related_keys_set_string (relkeys,
                                GRL_METADATA_KEY_REGION,
                                region);
@@ -878,7 +887,11 @@ grl_media_add_region_data (GrlMedia *media,
                            const GDateTime *publication_date,
                            const gchar *certificate)
 {
-  GrlRelatedKeys *relkeys = grl_related_keys_new ();
+  GrlRelatedKeys *relkeys;
+
+  g_return_if_fail (GRL_IS_MEDIA (media));
+
+  relkeys = grl_related_keys_new ();
   grl_related_keys_set_string (relkeys,
                                GRL_METADATA_KEY_REGION,
                                region);
@@ -1129,11 +1142,11 @@ grl_media_set_keyword (GrlMedia *media,
  * Since: 0.2.10
  */
 void
-grl_media_set_size (GrlMedia *media, gint size)
+grl_media_set_size (GrlMedia *media, gint64 size)
 {
-  grl_data_set_int (GRL_DATA (media),
-                    GRL_METADATA_KEY_SIZE,
-                    size);
+  grl_data_set_int64 (GRL_DATA (media),
+                      GRL_METADATA_KEY_SIZE,
+                      size);
 }
 
 /**
@@ -1192,8 +1205,11 @@ grl_media_get_url_data (GrlMedia *media, gchar **mime)
 const gchar *
 grl_media_get_url_data_nth (GrlMedia *media, guint index, gchar **mime)
 {
-  GrlRelatedKeys *relkeys =
-    grl_data_get_related_keys (GRL_DATA (media), GRL_METADATA_KEY_URL, index);
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys = grl_data_get_related_keys (GRL_DATA (media), GRL_METADATA_KEY_URL, index);
 
   if (!relkeys) {
     return NULL;
@@ -1233,7 +1249,11 @@ grl_media_get_author (GrlMedia *media)
 const gchar *
 grl_media_get_author_nth (GrlMedia *media, guint index)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_AUTHOR,
                                index);
@@ -1313,7 +1333,11 @@ grl_media_get_thumbnail (GrlMedia *media)
 const gchar *
 grl_media_get_thumbnail_nth (GrlMedia *media, guint index)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_THUMBNAIL,
                                index);
@@ -1356,7 +1380,11 @@ grl_media_get_thumbnail_binary (GrlMedia *media, gsize *size)
 const guint8 *
 grl_media_get_thumbnail_binary_nth (GrlMedia *media, gsize *size, guint index)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_THUMBNAIL,
                                index);
@@ -1488,26 +1516,30 @@ grl_media_get_region_data_nth (GrlMedia *media,
                                const GDateTime **publication_date,
                                const gchar **certificate)
 {
-    GrlRelatedKeys *relkeys =
-      grl_data_get_related_keys (GRL_DATA (media),
-                                 GRL_METADATA_KEY_PUBLICATION_DATE,
-                                 index);
+  GrlRelatedKeys *relkeys;
 
-    if (!relkeys) {
-      return NULL;
-    }
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
 
-    if (publication_date) {
-      *publication_date = grl_related_keys_get_boxed
-                (relkeys, GRL_METADATA_KEY_PUBLICATION_DATE);
-    }
+  relkeys =
+    grl_data_get_related_keys (GRL_DATA (media),
+                               GRL_METADATA_KEY_PUBLICATION_DATE,
+                               index);
 
-    if (certificate) {
-      *certificate = grl_related_keys_get_string
-                (relkeys, GRL_METADATA_KEY_CERTIFICATE);
-    }
+  if (!relkeys) {
+    return NULL;
+  }
 
-    return grl_related_keys_get_string (relkeys, GRL_METADATA_KEY_REGION);
+  if (publication_date) {
+    *publication_date = grl_related_keys_get_boxed
+              (relkeys, GRL_METADATA_KEY_PUBLICATION_DATE);
+  }
+
+  if (certificate) {
+    *certificate = grl_related_keys_get_string
+              (relkeys, GRL_METADATA_KEY_CERTIFICATE);
+  }
+
+  return grl_related_keys_get_string (relkeys, GRL_METADATA_KEY_REGION);
 }
 
 /**
@@ -1638,7 +1670,11 @@ grl_media_get_player(GrlMedia *media)
 const gchar *
 grl_media_get_player_nth (GrlMedia *media, guint index)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_EXTERNAL_PLAYER,
                                index);
@@ -1678,7 +1714,11 @@ grl_media_get_external_url (GrlMedia *media)
 const gchar *
 grl_media_get_external_url_nth (GrlMedia *media, guint index)
 {
-  GrlRelatedKeys *relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_EXTERNAL_URL,
                                index);
@@ -1794,7 +1834,11 @@ const gchar *
 grl_media_get_keyword_nth (GrlMedia *media,
                            guint index)
 {
-  GrlRelatedKeys *const relkeys =
+  GrlRelatedKeys *relkeys;
+
+  g_return_val_if_fail (GRL_IS_MEDIA (media), NULL);
+
+  relkeys =
     grl_data_get_related_keys (GRL_DATA (media),
                                GRL_METADATA_KEY_KEYWORD,
                                index);
@@ -1815,9 +1859,9 @@ grl_media_get_keyword_nth (GrlMedia *media,
  *
  * since: 0.2.10
  */
-gint
+gint64
 grl_media_get_size (GrlMedia *media)
 {
   g_return_val_if_fail (GRL_IS_MEDIA (media), -1);
-  return grl_data_get_int (GRL_DATA (media), GRL_METADATA_KEY_SIZE);
+  return grl_data_get_int64 (GRL_DATA (media), GRL_METADATA_KEY_SIZE);
 }
