@@ -62,6 +62,20 @@ GRL_LOG_DOMAIN(registry_log_domain);
 
 #define GRL_PLUGIN_INFO_MODULE "module"
 
+#define LOCAL_NET_TAG      "net:local"
+#define INTERNET_NET_TAG   "net:internet"
+
+#ifdef HAVE_GIO_WITH_NETMON
+#define SET_INVISIBLE_SOURCE(src, val)                          \
+  g_object_set_data(G_OBJECT(src), "invisible", GINT_TO_POINTER(val))
+#define SOURCE_IS_INVISIBLE(src)                                \
+  GPOINTER_TO_INT(g_object_get_data(G_OBJECT(src), "invisible"))
+#else
+#define SET_INVISIBLE_SOURCE(src, val)
+#define SOURCE_IS_INVISIBLE(src)                                \
+  FALSE
+#endif /* HAVE_GIO_WITH_NETMON */
+
 #define GRL_REGISTRY_GET_PRIVATE(object)                        \
   (G_TYPE_INSTANCE_GET_PRIVATE((object),                        \
                                GRL_TYPE_REGISTRY,               \
@@ -85,6 +99,9 @@ struct _GrlRegistryPrivate {
   GSList *allowed_plugins;
   gboolean all_plugins_preloaded;
   struct KeyIDHandler key_id_handler;
+#ifdef HAVE_GIO_WITH_NETMON
+  GNetworkMonitor *netmon;
+#endif
 };
 
 static void grl_registry_setup_ranks (GrlRegistry *registry);
@@ -109,6 +126,14 @@ static void shutdown_plugin (GrlPlugin *plugin);
 
 static void configs_free (GList *configs);
 
+#ifdef HAVE_GIO_WITH_NETMON
+static gboolean strv_contains (const char **strv, const char  *str);
+#endif
+
+static GrlPlugin *grl_registry_prepare_plugin (GrlRegistry *registry,
+                                               const gchar *library_filename,
+                                               GError **error);
+
 /* ================ GrlRegistry GObject ================ */
 
 enum {
@@ -184,6 +209,83 @@ grl_registry_class_init (GrlRegistryClass *klass)
                  G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
+#ifdef HAVE_GIO_WITH_NETMON
+static void
+network_changed_cb (GObject     *gobject,
+                    GParamSpec  *pspec,
+                    GrlRegistry *registry)
+{
+  GNetworkConnectivity connectivity;
+  gboolean network_available;
+  GHashTableIter iter;
+  GrlSource *current_source;
+
+  GRL_DEBUG ("Network availability changed");
+
+  g_object_get (G_OBJECT (registry->priv->netmon),
+                "connectivity", &connectivity,
+                "network-available", &network_available,
+                NULL);
+
+  GRL_DEBUG ("Connectivity level is %d, Network is %s",
+             connectivity, network_available ? "available" : "unavailable");
+
+  if (!network_available) {
+    g_hash_table_iter_init (&iter, registry->priv->sources);
+
+    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &current_source)) {
+      const char **tags = grl_source_get_tags (current_source);
+
+      if (!tags)
+        continue;
+
+      if ((strv_contains (tags, LOCAL_NET_TAG) ||
+           strv_contains (tags, INTERNET_NET_TAG)) &&
+          !SOURCE_IS_INVISIBLE(current_source)) {
+        GRL_DEBUG ("Network isn't available for '%s', hiding",
+                   grl_source_get_id (current_source));
+        SET_INVISIBLE_SOURCE(current_source, TRUE);
+        g_signal_emit (registry, registry_signals[SIG_SOURCE_REMOVED], 0, current_source);
+      }
+    }
+  } else {
+    g_hash_table_iter_init (&iter, registry->priv->sources);
+    while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &current_source)) {
+      const char **tags = grl_source_get_tags (current_source);
+
+      if (!tags)
+        continue;
+
+      if (strv_contains (tags, LOCAL_NET_TAG) &&
+          SOURCE_IS_INVISIBLE(current_source)) {
+        GRL_DEBUG ("Local network became available for '%s', showing",
+                   grl_source_get_id (current_source));
+        SET_INVISIBLE_SOURCE(current_source, FALSE);
+        g_signal_emit (registry, registry_signals[SIG_SOURCE_ADDED], 0, current_source);
+      }
+
+      if (strv_contains (tags, INTERNET_NET_TAG) &&
+          connectivity == G_NETWORK_CONNECTIVITY_FULL &&
+          SOURCE_IS_INVISIBLE(current_source)) {
+        GRL_DEBUG ("Internet became available for '%s', showing",
+                   grl_source_get_id (current_source));
+        SET_INVISIBLE_SOURCE(current_source, FALSE);
+        g_signal_emit (registry, registry_signals[SIG_SOURCE_ADDED], 0, current_source);
+      }
+
+      if (strv_contains (tags, INTERNET_NET_TAG) &&
+          connectivity != G_NETWORK_CONNECTIVITY_FULL &&
+          !SOURCE_IS_INVISIBLE(current_source)) {
+        GRL_DEBUG ("Internet became unavailable for '%s', hiding",
+                   grl_source_get_id (current_source));
+        SET_INVISIBLE_SOURCE(current_source, TRUE);
+        g_signal_emit (registry, registry_signals[SIG_SOURCE_REMOVED], 0, current_source);
+      }
+    }
+  }
+}
+#endif /* HAVE_GIO_WITH_NETMON */
+
 static void
 grl_registry_init (GrlRegistry *registry)
 {
@@ -200,6 +302,14 @@ grl_registry_init (GrlRegistry *registry)
   registry->priv->system_keys =
     g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify) g_param_spec_unref);
 
+#ifdef HAVE_GIO_WITH_NETMON
+  registry->priv->netmon = g_network_monitor_get_default ();
+  g_signal_connect (G_OBJECT (registry->priv->netmon), "notify::connectivity",
+                    G_CALLBACK (network_changed_cb), registry);
+  g_signal_connect (G_OBJECT (registry->priv->netmon), "notify::network-available",
+                    G_CALLBACK (network_changed_cb), registry);
+#endif
+
   key_id_handler_init (&registry->priv->key_id_handler);
 
   grl_registry_setup_ranks (registry);
@@ -213,6 +323,73 @@ configs_free (GList *configs)
   g_list_free_full (configs, g_object_unref);
 }
 
+#ifdef HAVE_GIO_WITH_NETMON
+static gboolean
+strv_contains (const char **strv,
+               const char  *str)
+{
+  const char **s = strv;
+
+  while (*s) {
+    if (g_str_equal (str, *s))
+      return TRUE;
+    s++;
+  }
+
+  return FALSE;
+}
+
+static void
+update_source_visibility (GrlRegistry *registry,
+                          GrlSource   *source)
+{
+  GNetworkConnectivity connectivity;
+  gboolean network_available;
+  const char **tags;
+  gboolean needs_local, needs_inet;
+
+  tags = grl_source_get_tags (source);
+  if (!tags)
+    return;
+
+  needs_local = strv_contains (tags, LOCAL_NET_TAG);
+  needs_inet = strv_contains (tags, INTERNET_NET_TAG);
+
+  if (!needs_local &&
+      !needs_inet)
+    return;
+
+  g_object_get (G_OBJECT (registry->priv->netmon),
+                "connectivity", &connectivity,
+                "network-available", &network_available,
+                NULL);
+
+  GRL_DEBUG ("Connectivity level is %d, Network is %s",
+             connectivity, network_available ? "available" : "unavailable");
+  GRL_DEBUG ("Source %s needs %s %s%s",
+             grl_source_get_id (source),
+             needs_local ? "local network" : "",
+             needs_inet && needs_local ? " and " : "",
+             needs_inet ? "Internet" : "");
+
+  if (!network_available) {
+    if (needs_local || needs_inet) {
+      GRL_DEBUG ("Network isn't available for '%s', hiding",
+                 grl_source_get_id (source));
+      SET_INVISIBLE_SOURCE(source, TRUE);
+    }
+  } else {
+    if (connectivity != G_NETWORK_CONNECTIVITY_FULL) {
+      if (needs_inet) {
+        GRL_DEBUG ("Internet isn't available for '%s', hiding",
+                   grl_source_get_id (source));
+        SET_INVISIBLE_SOURCE(source, TRUE);
+      }
+    }
+  }
+}
+#endif /* HAVE_GIO_WITH_NETMON */
+
 static void
 config_source_rank (GrlRegistry *registry,
                     const gchar *source_id,
@@ -343,12 +520,11 @@ get_info_from_plugin_xml (const gchar *xml_path)
 }
 
 static gboolean
-activate_plugin (GrlRegistry *registry,
-                 GrlPlugin *plugin,
-                 GError **error)
+register_keys_plugin (GrlRegistry *registry,
+                      GrlPlugin *plugin,
+                      GError **error)
 {
   gboolean is_loaded;
-  GList *plugin_configs;
 
   /* Check if plugin is already loaded */
   g_object_get (plugin, "loaded", &is_loaded, NULL);
@@ -361,6 +537,18 @@ activate_plugin (GrlRegistry *registry,
     return FALSE;
   }
 
+  grl_plugin_register_keys (plugin);
+
+  return TRUE;
+}
+
+static gboolean
+activate_plugin (GrlRegistry *registry,
+                 GrlPlugin *plugin,
+                 GError **error)
+{
+  GList *plugin_configs;
+
   plugin_configs = g_hash_table_lookup (registry->priv->configs,
                                         grl_plugin_get_id (plugin));
 
@@ -512,19 +700,24 @@ static gboolean
 grl_registry_load_plugin_list (GrlRegistry *registry,
                                GList *plugin_list)
 {
-  GrlPlugin *plugin;
+  GList *l;
   gboolean loaded_one = FALSE;
 
-  while (plugin_list) {
-    plugin = (GrlPlugin *) plugin_list->data;
+  for (l = plugin_list; l ; l = l->next) {
+    GrlPlugin *plugin = l->data;
     if (grl_plugin_get_module (plugin)) {
-      loaded_one |= activate_plugin (registry, plugin, NULL);
+      loaded_one |= register_keys_plugin (registry, plugin, NULL);
     } else {
-      loaded_one |= grl_registry_load_plugin (registry,
-                                              grl_plugin_get_filename (plugin),
-                                              NULL);
+      loaded_one |= (grl_registry_prepare_plugin (registry,
+                                                  grl_plugin_get_filename (plugin),
+                                                  NULL) != NULL);
+      loaded_one |= register_keys_plugin (registry, plugin, NULL);
     }
-    plugin_list = g_list_next (plugin_list);
+  }
+
+  for (l = plugin_list; l ; l = l->next) {
+    GrlPlugin *plugin = l->data;
+    loaded_one |= activate_plugin (registry, plugin, NULL);
   }
 
   return loaded_one;
@@ -559,7 +752,7 @@ grl_registry_register_metadata_key_full (GrlRegistry *registry,
 
   g_hash_table_insert (registry->priv->system_keys,
                        (gpointer) key_name,
-                       g_param_spec_ref (param_spec));
+                       param_spec);
 
   /* Each key is related to itself */
   g_hash_table_insert (registry->priv->related_keys,
@@ -804,7 +997,7 @@ grl_registry_get_default (void)
  * grl_registry_register_source:
  * @registry: the registry instance
  * @plugin: the plugin which owns the source
- * @source: the source to register
+ * @source: (transfer full): the source to register
  * @error: error return location or @NULL to ignore
  *
  * Register a @source in the @registry with the given @plugin information
@@ -842,7 +1035,13 @@ grl_registry_register_source (GrlRegistry *registry,
   /* Set source rank */
   set_source_rank (registry, source);
 
-  g_signal_emit (registry, registry_signals[SIG_SOURCE_ADDED], 0, source);
+#ifdef HAVE_GIO_WITH_NETMON
+  /* Update whether it should be invisible */
+  update_source_visibility (registry, source);
+#endif
+
+  if (!SOURCE_IS_INVISIBLE(source))
+    g_signal_emit (registry, registry_signals[SIG_SOURCE_ADDED], 0, source);
 
   return TRUE;
 }
@@ -913,22 +1112,10 @@ grl_registry_add_directory (GrlRegistry *registry,
   registry->priv->all_plugins_preloaded = FALSE;
 }
 
-/**
- * grl_registry_load_plugin:
- * @registry: the registry instance
- * @library_filename: the path to the so file
- * @error: error return location or @NULL to ignore
- *
- * Loads a module from shared object file stored in @path
- *
- * Returns: %TRUE if the module is loaded correctly
- *
- * Since: 0.2.0
- */
-gboolean
-grl_registry_load_plugin (GrlRegistry *registry,
-                          const gchar *library_filename,
-                          GError **error)
+static GrlPlugin *
+grl_registry_prepare_plugin (GrlRegistry *registry,
+                             const gchar *library_filename,
+                             GError **error)
 {
   GModule *module;
   GrlPluginDescriptor *plugin_desc;
@@ -946,7 +1133,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
                  GRL_CORE_ERROR,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
                  _("Failed to load plugin from %s"), library_filename);
-    return FALSE;
+    return NULL;
   }
 
   if (!g_module_symbol (module, "GRL_PLUGIN_DESCRIPTOR", (gpointer) &plugin_desc)) {
@@ -956,7 +1143,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
                  _("Invalid plugin file %s"), library_filename);
     g_module_close (module);
-    return FALSE;
+    return NULL;
   }
 
   if (!plugin_desc->plugin_init ||
@@ -967,7 +1154,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
                  GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
                  _("'%s' is not a valid plugin file"), library_filename);
     g_module_close (module);
-    return FALSE;
+    return NULL;
   }
 
   /* Check if plugin is preloaded; if not, then create one */
@@ -986,7 +1173,7 @@ grl_registry_load_plugin (GrlRegistry *registry,
                    GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
                    _("Unable to load plugin '%s'"), plugin_desc->plugin_id);
       g_module_close (module);
-      return FALSE;
+      return NULL;
     }
   } else {
     /* Check if the existent plugin is for a different module */
@@ -996,13 +1183,14 @@ grl_registry_load_plugin (GrlRegistry *registry,
                    GRL_CORE_ERROR,
                    GRL_CORE_ERROR_LOAD_PLUGIN_FAILED,
                    _("Plugin '%s' already exists"), library_filename);
-      return FALSE;
+      return NULL;
     }
   }
 
   if (!grl_plugin_get_module (plugin)) {
     grl_plugin_set_load_func (plugin, plugin_desc->plugin_init);
     grl_plugin_set_unload_func (plugin, plugin_desc->plugin_deinit);
+    grl_plugin_set_register_keys_func (plugin, plugin_desc->plugin_register_keys);
 
     /* Insert module name as part of plugin information */
     module_name = g_path_get_basename (library_filename);
@@ -1015,7 +1203,34 @@ grl_registry_load_plugin (GrlRegistry *registry,
     g_module_make_resident (module);
   }
 
-  return activate_plugin (registry, plugin, error);
+  return plugin;
+}
+
+/**
+ * grl_registry_load_plugin:
+ * @registry: the registry instance
+ * @library_filename: the path to the so file
+ * @error: error return location or @NULL to ignore
+ *
+ * Loads a module from shared object file stored in @path
+ *
+ * Returns: %TRUE if the module is loaded correctly
+ *
+ * Since: 0.2.0
+ */
+gboolean
+grl_registry_load_plugin (GrlRegistry *registry,
+                          const gchar *library_filename,
+                          GError **error)
+{
+  GrlPlugin *plugin;
+
+  plugin = grl_registry_prepare_plugin (registry, library_filename, error);
+  if (!plugin)
+    return FALSE;
+
+  return register_keys_plugin (registry, plugin, error) &&
+         activate_plugin (registry, plugin, error);
 }
 
 /**
@@ -1173,11 +1388,16 @@ GrlSource *
 grl_registry_lookup_source (GrlRegistry *registry,
                             const gchar *source_id)
 {
+  GrlSource *source;
+
   g_return_val_if_fail (GRL_IS_REGISTRY (registry), NULL);
   g_return_val_if_fail (source_id != NULL, NULL);
 
-  return (GrlSource *) g_hash_table_lookup (registry->priv->sources,
-                                            source_id);
+  source = (GrlSource *) g_hash_table_lookup (registry->priv->sources,
+                                              source_id);
+  if (source && !SOURCE_IS_INVISIBLE(source))
+    return source;
+  return NULL;
 }
 
 /**
@@ -1207,7 +1427,8 @@ grl_registry_get_sources (GrlRegistry *registry,
 
   g_hash_table_iter_init (&iter, registry->priv->sources);
   while (g_hash_table_iter_next (&iter, NULL, (gpointer *) &current_source)) {
-    source_list = g_list_prepend (source_list, current_source);
+    if (!SOURCE_IS_INVISIBLE(current_source))
+      source_list = g_list_prepend (source_list, current_source);
   }
 
   if (ranked) {
@@ -1250,7 +1471,8 @@ grl_registry_get_sources_by_operations (GrlRegistry *registry,
     GrlSupportedOps source_ops;
     source_ops =
       grl_source_supported_operations (source);
-    if ((source_ops & ops) == ops) {
+    if ((source_ops & ops) == ops &&
+        !SOURCE_IS_INVISIBLE(source)) {
       source_list = g_list_prepend (source_list, source);
     }
   }
@@ -1386,7 +1608,7 @@ grl_registry_unload_plugin (GrlRegistry *registry,
 /**
  * grl_registry_register_metadata_key:
  * @registry: The plugin registry
- * @param_spec: The definition of the key to register
+ * @param_spec: (transfer full): The definition of the key to register
  * @error: error return location or @NULL to ignore
  *
  * Registers a metadata key
@@ -1437,7 +1659,6 @@ grl_registry_register_metadata_key_system (GrlRegistry *registry,
                                                             param_spec,
                                                             key,
                                                             error);
-  g_param_spec_unref (param_spec);
 
   return registered_key;
 }
